.jsfh-animated-property {
    animation: eclair;
    animation-iteration-count: 1;
    animation-fill-mode: forwards;
    animation-duration: 0.75s
}

@keyframes eclair {
    0%, 100% {
        transform: scale(1)
    }
    50% {
        transform: scale(1.03)
    }
}
