<div class="not-value">
    <h4>Must <strong>not</strong> be:</h4>
    <div class="card">
        <div class="card-body" id="{{ card_id }}">
            {{ content(schema.kw_not) }}
        </div>
    </div>
</div>